pub struct CredentialsError {
pub message: String,
}Expand description
Represents an Error that has occured during the fetching Credentials Phase.
This generally is an error message from one of our underlying libraries, however we wrap it up with this type so we can export one single error type.
Fields
message: StringThe underlying error message for the credentials error.
Implementations
Sourceimpl CredentialsError
impl CredentialsError
Sourcepub fn new<S>(message: S) -> CredentialsErrorwhere
S: ToString,
pub fn new<S>(message: S) -> CredentialsErrorwhere
S: ToString,
Creates a new Credentials Error.
message- The Error message for this CredentialsError.