pub struct InstanceMetadataProvider { /* private fields */ }Expand description
Provides AWS credentials from a resource’s IAM role.
The provider has a default timeout of 30 seconds. While it should work well for most setups,
you can change the timeout using the set_timeout method.
Examples
use std::time::Duration;
use rusoto_credential::InstanceMetadataProvider;
let mut provider = InstanceMetadataProvider::new();
// you can overwrite the default timeout like this:
provider.set_timeout(Duration::from_secs(60));The source location can be changed from the default of 169.254.169.254:
use std::time::Duration;
use rusoto_credential::InstanceMetadataProvider;
let mut provider = InstanceMetadataProvider::new();
// you can overwrite the default endpoint like this:
provider.set_ip_addr_with_port("127.0.0.1", "8080");Implementations
Sourceimpl InstanceMetadataProvider
impl InstanceMetadataProvider
Sourcepub fn set_timeout(&mut self, timeout: Duration)
pub fn set_timeout(&mut self, timeout: Duration)
Set the timeout on the provider to the specified duration.
Sourcepub fn set_ip_addr_with_port(&mut self, ip: &str, port: &str)
pub fn set_ip_addr_with_port(&mut self, ip: &str, port: &str)
Allow overriding host and port of instance metadata service.